<?php
/**
 * Metabox config file.
 *
 * @link       https://shapedplugin.com
 * @since      3.0.0
 *
 * @package    WP_Carousel_Pro
 * @subpackage WP_Carousel_Pro/admin/views
 */

use ShapedPlugin\WPCarouselPro\Admin\views\sp_framework\classes\SP_WPCP_Framework;
if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.

//
// Create a metabox.
//
SP_WPCP_Framework::createMetabox(
	$wpcp_carousel_shortcode_settings,
	array(
		'title'        => __( 'Shortcode Section', 'wp-carousel-pro' ),
		'post_type'    => 'sp_wp_carousel',
		'show_restore' => false,
		'theme'        => 'light',
		'class'        => 'sp_wpcp_shortcode_generator',
		'nav'          => 'inline',
	)
);

//
// General section.
//
SP_WPCP_Framework::createSection(
	$wpcp_carousel_shortcode_settings,
	array(
		'title'  => __( 'General Settings', 'wp-carousel-pro' ),
		'icon'   => 'fa fa-cog',
		'fields' => array(
			array(
				'id'       => 'wpcp_layout',
				'class'    => 'wpcp_layout',
				'type'     => 'image_select',
				'title'    => __( 'Layout Type', 'wp-carousel-pro' ),
				'subtitle' => __( 'Choose a layout type.', 'wp-carousel-pro' ),
				'options'  => array(
					'carousel'          => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/carousel.svg',
						'text'  => __( 'Carousel', 'wp-carousel-pro' ),
					),
					'grid'              => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/grid.svg',
						'text'  => __( 'Grid', 'wp-carousel-pro' ),
					),
					'tiles'             => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/tiles.svg',
						'text'  => __( 'Tiles', 'wp-carousel-pro' ),
					),
					'masonry'           => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/masonry.svg',
						'text'  => __( 'Masonry', 'wp-carousel-pro' ),
					),
					'justified'         => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/justified.svg',
						'text'  => __( 'Justified', 'wp-carousel-pro' ),
					),
					'thumbnails-slider' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/layouts/thumbnails-slider.svg',
						'text'  => __( 'Thumbs Slider', 'wp-carousel-pro' ),
					),
				),
				'default'  => 'carousel',
			),
			array(
				'id'         => 'wpcp_thumbnail_position',
				'type'       => 'image_select',
				'class'      => 'wpcp_thumbnail_position',
				'title'      => __( 'Thumbnails Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose a thumbnails position.', 'wp-carousel-pro' ),
				'options'    => array(
					'bottom' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/thumbnail_position_bottom.svg',
						'text'  => __( 'Bottom', 'wp-carousel-pro' ),
					),
					'top'    => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/thumbnail_position_top.svg',
						'text'  => __( 'Top', 'wp-carousel-pro' ),
					),
					'left'   => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/thumbnail_position_left.svg',
						'text'  => __( 'Left', 'wp-carousel-pro' ),
					),
					'right'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/thumbnail_position_right.svg',
						'text'  => __( 'Right', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom',
				'dependency' => array( 'wpcp_layout', '==', 'thumbnails-slider', true ),
			),
			array(
				'id'         => 'wpcp_carousel_mode',
				'class'      => 'wpcp_carousel_mode wpcp_thumbnail_position',
				'type'       => 'image_select',
				'title'      => __( 'Carousel Mode', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set carousel mode. Carousel controls are disabled in the ticker mode.', 'wp-carousel-pro' ),
				'title_help' => __( '<div class="sp_wpcp-info-label">Carousel Mode</div><div class="sp_wpcp-short-content">Choose <b>Standard</b> for a classic display, <b>Ticker</b> for continuous scrolling, or <b>Center</b> for a focused and immersive view.</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-configure-carousel-mode/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/carousel-modes/" target="_blank">Live Demo</a>', 'wp-carousel-pro' ),
				'options'    => array(
					'standard' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/carousel-mode/carousel_standard.svg',
						'text'  => __( 'Standard', 'wp-carousel-pro' ),
					),
					'ticker'   => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/carousel-mode/carousel_ticker.svg',
						'text'  => __( 'Ticker', 'wp-carousel-pro' ),
					),
					'center'   => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/carousel-mode/carousel_center.svg',
						'text'  => __( 'Center', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'standard',
				'dependency' => array( 'wpcp_layout', '==', 'carousel' ),
			),
			array(
				'id'         => 'wpcp_slide_margin',
				'class'      => 'wpcp-slide-margin standard_width_of_spacing_field',
				'type'       => 'spacing',
				'title'      => __( 'Space', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a space between the items.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/space.svg" alt="Space"></div><div class="sp_wpcp-info-label">' . __( 'Space', 'wp-carousel-pro' ) . '</div>',
				'right'      => true,
				'top'        => true,
				'left'       => false,
				'bottom'     => false,
				'right_text' => 'Vertical Gap',
				'top_text'   => 'Gap',
				'right_icon' => '<i class="fa fa-arrows-v"></i>',
				'top_icon'   => '<i class="fa fa-arrows-h"></i>',
				'unit'       => true,
				'units'      => array( 'px' ),
				'default'    => array(
					'top'   => '20',
					'right' => '20',
				),
			),
			array(
				'id'         => 'thumbnails_orientation',
				'type'       => 'button_set',
				'title'      => __( 'Slider Orientation', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose an orientation for thumbnail slider.', 'wp-carousel-pro' ),
				'title_help' => __(
					'<div class="sp_wpcp-info-label">Slider Orientation</div><div class="sp_wpcp-short-content">
					<strong style="font-weight: 700;">Horizontal</strong>: If you want the slides to transition horizontally, select <b>Horizontal</b>.<br>
					<strong style="font-weight: 700;">Vertical</strong>:  If you want the slides to transition vertically, select <b>Vertical</b></div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-configure-the-carousel-orientation/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/carousel-orientations/" target="_blank">Live Demo</a>',
					'wp-carousel-pro'
				),
				'options'    => array(
					'horizontal' => __( 'Horizontal', 'wp-carousel-pro' ),
					'vertical'   => __( 'Vertical', 'wp-carousel-pro' ),
				),
				'default'    => 'horizontal',
				'dependency' => array( 'wpcp_layout', '==', 'thumbnails-slider' ),
			),
			array(
				'id'         => 'thumbnails_hide_on_mobile',
				'type'       => 'checkbox',
				'title'      => __( 'Hide Thumbnails On Mobile', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable/Disable thumbnails hide on mobile.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_layout', '==', 'thumbnails-slider' ),
			),
			array(
				'id'         => 'thumbnails_height_type',
				'type'       => 'select',
				'title'      => __( 'Thumbnails Height', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose a type thumbnails height.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/thumbnail-height.svg" alt="Thumbnails Height"></div><div class="sp_wpcp-info-label">' . __( 'Thumbnails Height', 'wp-carousel-pro' ) . '</div>',
				'options'    => array(
					'auto'   => __( 'Auto', 'wp-carousel-pro' ),
					'static' => __( 'Static', 'wp-carousel-pro' ),
				),
				'default'    => 'static',
				'dependency' => array( 'wpcp_layout|wpcp_thumbnail_position', '==|any', 'thumbnails-slider|top,bottom' ),
			),
			array(
				'id'         => 'thumbHeight',
				'type'       => 'spacing',
				'title'      => __( 'Thumbnails Static Height', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a height for the thumbnails.', 'wp-carousel-pro' ),
				'all'        => true,
				'all_text'   => '<i class="fa fa-arrows-v"></i>',
				'unit'       => true,
				'units'      => array( 'px', '%' ),
				'default'    => array(
					'all'  => '140',
					'unit' => 'px',
				),
				'dependency' => array( 'wpcp_layout|wpcp_thumbnail_position|thumbnails_height_type', '==|any|==', 'thumbnails-slider|top,bottom|static' ),
			),
			array(
				'id'         => 'rowHeight',
				'type'       => 'spacing',
				'class'      => 'standard_width_of_spacing_field',
				'title'      => __( 'Row Height', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a row height for justified layout.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/row-height.svg" alt="Row Height"></div><div class="sp_wpcp-info-label">' . __( 'Row Height', 'wp-carousel-pro' ) . '</div>',
				'all'        => true,
				'all_text'   => '<i class="fa fa-arrows-v"></i>',
				'unit'       => true,
				'units'      => array( 'px' ),
				'default'    => array(
					'all' => '250',
				),
				'dependency' => array( 'wpcp_layout', '==', 'justified' ),
			),
			array(
				'id'              => 'wpcp_slide_width',
				'type'            => 'spacing',
				'class'           => 'standard_width_of_spacing_field',
				'title'           => __( 'Items Width', 'wp-carousel-pro' ),
				'subtitle'        => __( 'Set a width for the each items.', 'wp-carousel-pro' ),
				'all'             => true,
				'all_text'        => '<i class="fa fa-arrows-h"></i>',
				'all_placeholder' => 'width',
				'default'         => array(
					'all' => '250',
				),
				'units'           => array(
					'px',
				),
				'attributes'      => array(
					'min' => 0,
				),
				'dependency'      => array( 'wpcp_carousel_mode|wpcp_layout', '==|==', 'ticker|carousel' ),
			),
			array(
				'id'         => 'wpcp_number_of_columns',
				'class'      => 'wpcp_number_of_columns standard_width_of_spacing_field',
				'type'       => 'column',
				'title'      => __( 'Column(s)', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set number of column on devices.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/column.svg" alt="Column(s)"></div><div class="sp_wpcp-info-label">' . __( 'Column(s)', 'wp-carousel-pro' ) . '</div>',
				'help'       => '<i class="fa fa-television"></i> LARGE DESKTOP - Screens larger than 1280px.<br/>
							<i class="fa fa-desktop"></i> DESKTOP - Screens smaller than 1280px.<br/>
							<i class="fa fa-laptop"></i> LAPTOP - Screens smaller than 980px.<br/>
							<i class="fa fa-tablet"></i> TABLET - Screens smaller than 736px.<br/>
							<i class="fa fa-mobile"></i> MOBILE - Screens smaller than 480px.<br/>',
				'default'    => array(
					'lg_desktop' => '5',
					'desktop'    => '4',
					'laptop'     => '3',
					'tablet'     => '2',
					'mobile'     => '1',
				),
				'min'        => '1',
				'dependency' => array( 'wpcp_carousel_mode', '!=', 'ticker' ),
			),
			array(
				'id'         => 'wpcp_image_center_mode_padding',
				'type'       => 'column',
				'title'      => __( 'Center Padding', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set center mode padding.', 'wp-carousel-pro' ),
				'unit'       => true,
				'units'      => array(
					'px',
				),
				'default'    => array(
					'lg_desktop' => '100',
					'desktop'    => '100',
					'laptop'     => '70',
					'tablet'     => '50',
					'mobile'     => '40',
				),
				'dependency' => array( 'wpcp_carousel_mode|wpcp_layout', '==|==', 'center|carousel' ),
			),
			array(
				'id'         => 'wpcp_number_of_columns_ticker',
				'type'       => 'column',
				'title'      => __( 'Column(s)', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set maximum & minimum column number.', 'wp-carousel-pro' ),
				'desktop'    => false,
				'laptop'     => false,
				'tablet'     => false,
				'default'    => array(
					'lg_desktop' => '5',
					'mobile'     => '2',
				),
				'dependency' => array( 'wpcp_carousel_mode|wpcp_layout', '==|==', 'ticker|carousel' ),
			),

			array(
				'id'     => 'wpcp_click_action_type_group',
				'class'  => 'wp-carousel-click-action-type',
				'type'   => 'fieldset',
				'fields' => array(
					array(
						'id'         => 'wpcp_logo_link_show',
						'type'       => 'image_select',
						'class'      => 'wpcp_logo_link_show_class',
						'title'      => __( 'Click Action Type', 'wp-carousel-pro' ),
						'options'    => array(
							'link'  => array(
								'image' => WPCAROUSEL_URL . 'Admin/img/url.svg',
							),
							'l_box' => array(
								'image' => WPCAROUSEL_URL . 'Admin/img/lightbox.svg',
							),
							'none'  => array(
								'image' => WPCAROUSEL_URL . 'Admin/img/disabled.svg',
							),
						),
						'subtitle'   => __( 'Choose a click action type for the items.', 'wp-carousel-pro' ),
						'default'    => 'l_box',
						'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,post-carousel,external-carousel', true ),
					),
					array(
						'id'         => 'wpcp_logo_link_nofollow',
						'type'       => 'checkbox',
						'class'      => 'wpcp_logo_link_nofollow',
						'title'      => __( 'Nofollow', 'wp-carousel-pro' ),
						'default'    => false,
						'dependency' => array( 'wpcp_carousel_type|wpcp_logo_link_show', 'any|not-any', 'image-carousel,post-carousel,external-carousel|none,l_box', true ),
					),
					array(
						'id'         => 'wpcp_link_open_target',
						'type'       => 'select',
						'class'      => 'wpcp_link_open_target',
						'title'      => __( 'Target', 'wp-carousel-pro' ),
						'options'    => array(
							'_self'  => __( 'Current Tab', 'wp-carousel-pro' ),
							'_blank' => __( 'New Tab', 'wp-carousel-pro' ),
						),
						'default'    => '_blank',
						'dependency' => array( 'wpcp_carousel_type|wpcp_logo_link_show', 'any|not-any', 'image-carousel,post-carousel,external-carousel|none,l_box', true ),
					),
				),
			),

			array(
				'id'         => 'wpcp_image_order_by',
				'type'       => 'select',
				'title'      => __( 'Order By', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set an order by option.', 'wp-carousel-pro' ),
				'options'    => array(
					'menu_order' => __( 'Drag & Drop', 'wp-carousel-pro' ),
					'rand'       => __( 'Random', 'wp-carousel-pro' ),
				),
				'default'    => 'menu_order',
				'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,video-carousel,content-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_order_by',
				'type'       => 'select',
				'title'      => __( 'Order By', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select an order by option.', 'wp-carousel-pro' ),
				'options'    => array(
					'ID'         => __( 'ID', 'wp-carousel-pro' ),
					'date'       => __( 'Date', 'wp-carousel-pro' ),
					'rand'       => __( 'Random', 'wp-carousel-pro' ),
					'title'      => __( 'Title', 'wp-carousel-pro' ),
					'modified'   => __( 'Modified', 'wp-carousel-pro' ),
					'menu_order' => __( 'Menu Order', 'wp-carousel-pro' ),
					'post__in'   => __( 'Drag & Drop', 'wp-carousel-pro' ),
				),
				'default'    => 'menu_order',
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_order',
				'type'       => 'select',
				'title'      => __( 'Order', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select an order option.', 'wp-carousel-pro' ),
				'options'    => array(
					'ASC'  => __( 'Ascending', 'wp-carousel-pro' ),
					'DESC' => __( 'Descending', 'wp-carousel-pro' ),
				),
				'default'    => 'rand',
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_scheduler',
				'type'       => 'switcher',
				'title'      => __( 'Scheduling', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable it to schedule sliders/galleries to show at specific time intervals.', 'wp-carousel-pro' ),
				'title_help' => __( '<div class="sp_wpcp-info-label">Scheduling</div><div class="sp_wpcp-short-content">Enable the scheduling feature to set the specific date and time for your carousel sliders or galleries to be displayed (perfect for highlighting time-sensitive content).</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-configure-the-scheduling-feature/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/scheduled-carousel/" target="_blank">Live Demo</a>', 'wp-carousel-pro' ),
				'default'    => false,
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
			),
			array(
				'id'         => 'wpcp_date_picker',
				'type'       => 'datetime',
				'title'      => '  ',
				'from_to'    => true,
				'help'       => __( 'Set a time according to your website time zone.', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_scheduler', '==', 'true', true ),
			),
			array(
				'id'         => 'wpcp_preloader',
				'type'       => 'switcher',
				'title'      => __( 'Preloader', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Items will be hidden until page load completed.', 'wp-carousel-pro' ),
				'default'    => true,
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
			),
			// Pagination.
			array(
				'type'       => 'subheading',
				'content'    => __( 'Pagination', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_layout', 'not-any', 'carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'wpcp_source_pagination',
				'type'       => 'switcher',
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'title'      => __( 'Pagination', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable to show pagination.', 'wp-carousel-pro' ),
				'default'    => true,
				'dependency' => array( 'wpcp_layout', 'not-any', 'carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'wpcp_pagination_type',
				'type'       => 'radio',
				'title'      => __( 'Pagination Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select pagination type.', 'wp-carousel-pro' ),
				'options'    => array(
					'load_more_btn'   => __( 'Load More Button(Ajax)', 'wp-carousel-pro' ),
					'infinite_scroll' => __( 'Load More on Infinite Scroll(Ajax)', 'wp-carousel-pro' ),
					'ajax_number'     => __( 'Number Pagination(Ajax)', 'wp-carousel-pro' ),
				),
				'default'    => 'load_more_btn',
				'dependency' => array( 'wpcp_carousel_type|wpcp_source_pagination|wpcp_layout', 'any|==|not-any', 'image-carousel,content-carousel,mix-content,external-carousel,video-carousel|true|carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'wpcp_post_pagination_type',
				'type'       => 'radio',
				'title'      => __( 'Pagination Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select pagination type.', 'wp-carousel-pro' ),
				'options'    => array(
					'load_more_btn'   => __( 'Load More Button', 'wp-carousel-pro' ),
					'infinite_scroll' => __( 'Load More on Infinite Scroll', 'wp-carousel-pro' ),
					'ajax_number'     => __( 'Ajax Number Pagination', 'wp-carousel-pro' ),
					'normal'          => __( 'No Ajax (Normal Pagination)', 'wp-carousel-pro' ),
				),
				'default'    => 'load_more_btn',
				'dependency' => array( 'wpcp_carousel_type|wpcp_source_pagination|wpcp_layout', 'any|==|not-any', 'post-carousel,product-carousel|true|carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'load_more_label',
				'type'       => 'text',
				'title'      => __( 'Load More Button Label', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Change load more button label.', 'wp-carousel-pro' ),
				'default'    => 'Load More',
				'dependency' => array( 'wpcp_source_pagination|wpcp_post_pagination_type|wpcp_pagination_type|wpcp_layout', '==|==|==|not-any', 'true|load_more_btn|load_more_btn|carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'post_per_page',
				'type'       => 'spinner',
				'title'      => __( 'Item(s) To Show Per Page', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set item(s) to show per page.', 'wp-carousel-pro' ),
				'default'    => '15',
				'min'        => 1,
				'max'        => 10000,
				'dependency' => array( 'wpcp_source_pagination|wpcp_layout', '==|not-any', 'true|carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'post_per_click',
				'type'       => 'spinner',
				'title'      => __( 'Item(s) To Show Per Click', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set item(s) to show per click.', 'wp-carousel-pro' ),
				'default'    => '10',
				'min'        => 1,
				'max'        => 10000,
				'dependency' => array( 'wpcp_carousel_type|wpcp_layout|wpcp_post_pagination_type|wpcp_source_pagination', 'any|not-any|any|==', 'post-carousel,product-carousel|carousel,thumbnails-slider|load_more_btn,infinite_scroll|true', true ),
			),
			array(
				'id'         => 'item_per_click',
				'type'       => 'spinner',
				'title'      => __( 'Item(s) To Show Per Click', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set item(s) to show per click.', 'wp-carousel-pro' ),
				'default'    => '10',
				'min'        => 1,
				'max'        => 10000,
				'dependency' => array( 'wpcp_source_pagination|wpcp_layout|wpcp_pagination_type|wpcp_carousel_type', '==|not-any|any|any', 'true|carousel,thumbnails-slider|load_more_btn,infinite_scroll|image-carousel,content-carousel,mix-content,external-carousel,video-carousel', true ),
			),
			array(
				'id'         => 'pagination_alignment',
				'type'       => 'button_set',
				'title'      => __( 'Alignment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose pagination alignment.', 'wp-carousel-pro' ),
				'options'    => array(
					'left'   => '<i class="fa fa-align-left" title="Left"></i>',
					'center' => '<i class="fa fa-align-center" title="Center"></i>',
					'right'  => '<i class="fa fa-align-right" title="Right"></i>',
				),
				'default'    => 'center',
				'dependency' => array( 'wpcp_source_pagination|wpcp_layout', '==|not-any', 'true|carousel,thumbnails-slider', true ),
			),
			array(
				'id'         => 'pagination_color',
				'type'       => 'color_group',
				'title'      => __( 'Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set pagination color.', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_source_pagination|wpcp_layout', '==|not-any', 'true|carousel,thumbnails-slider', true ),
				'options'    => array(
					'color'        => __( 'Color', 'wp-carousel-pro' ),
					'hover_color'  => __( 'Hover Color', 'wp-carousel-pro' ),
					'bg'           => __( 'Background', 'wp-carousel-pro' ),
					'hover_bg'     => __( 'Hover Background', 'wp-carousel-pro' ),
					'border'       => __( 'Border', 'wp-carousel-pro' ),
					'hover_border' => __( 'Hover Border', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color'        => '#5e5e5e',
					'hover_color'  => '#ffffff',
					'bg'           => '#ffffff',
					'hover_bg'     => '#178087',
					'border'       => '#dddddd',
					'hover_border' => '#178087',
				),
			),
		), // Fields array end.
	)
); // End of Upload section.
