<?php
/**
 * Metabox config file.
 *
 * @link       https://shapedplugin.com
 * @since      3.0.0
 *
 * @package    WP_Carousel_Pro
 * @subpackage WP_Carousel_Pro/admin/views
 */

use ShapedPlugin\WPCarouselPro\Admin\views\sp_framework\classes\SP_WPCP_Framework;

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.
//
// Image settings section begin.
//
SP_WPCP_Framework::createSection(
	$wpcp_carousel_shortcode_settings,
	array(
		'title'  => __( 'Image Settings', 'wp-carousel-pro' ),
		'icon'   => 'fa fa-picture-o',
		'fields' => array(
			// Image.
			array(
				'id'         => 'show_image',
				'type'       => 'switcher',
				'title'      => __( 'Image', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide slide image.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_image_sizes',
				'type'       => 'image_sizes',
				'chosen'     => true,
				'title'      => __( 'Image Size', 'wp-carousel-pro' ),
				'default'    => 'medium',
				'subtitle'   => __( 'Set a size for the image.', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel,video-carousel|true', true ),
			),
			array(
				'id'                => 'wpcp_image_crop_size',
				'type'              => 'dimensions_advanced',
				'class'             => 'standard_width_of_spacing_field',
				'title'             => __( 'Custom Size', 'wp-carousel-pro' ),
				'subtitle'          => __( 'Set width and height of the image.', 'wp-carousel-pro' ),
				'chosen'            => true,
				'bottom'            => false,
				'left'              => false,
				'color'             => false,
				'top_text'          => __( 'Width', 'wp-carousel-pro' ),
				'right_text'        => __( 'Height', 'wp-carousel-pro' ),
				'style_text'        => __( 'Crop', 'wp-carousel-pro' ),
				'top_icon'          => '<i class="fa fa-arrows-h"></i>',
				'right_icon'        => '<i class="fa fa-arrows-v"></i>',
				'top_placeholder'   => 'width',
				'right_placeholder' => 'height',
				'styles'            => array(
					'Soft-crop',
					'Hard-crop',
				),
				'default'           => array(
					'top'   => '600',
					'right' => '400',
					'style' => 'Soft-crop',
					'unit'  => 'px',
				),
				'attributes'        => array(
					'min' => 0,
				),
				'dependency'        => array( 'wpcp_carousel_type|show_image|wpcp_image_sizes', 'any|==|==', 'image-carousel,post-carousel,product-carousel,video-carousel|true|custom', true ),
			),
			array(
				'id'         => 'load_2x_image',
				'type'       => 'switcher',
				'title'      => __( 'Load 2x Resolution Image in Retina Display', 'wp-carousel-pro' ),
				'subtitle'   => __( 'You should upload 2x sized images to show in retina display.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type|show_image|wpcp_image_sizes', 'any|==|==', 'image-carousel,post-carousel,product-carousel|true|custom', true ),
			),
			array(
				'id'                 => 'wpcp_image_height_css',
				'type'               => 'dimensions_advanced',
				'class'              => 'dimensions_advanced_field',
				'title'              => __( 'Image Height CSS', 'wp-carousel-pro' ),
				'subtitle'           => __( 'Set image height on different devices for perfect responsive in px.', 'wp-carousel-pro' ),
				'title_help'         => __( '<div class="sp_wpcp-info-label">Image Height CSS</div><div class="sp_wpcp-short-content">Set image height on various devices for ideal responsiveness. Ensure your content looks great on every screen size with customized image heights.</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-configure-the-image-height-css/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/carousel-orientations/" target="_blank">Live Demo</a>', 'wp-carousel-pro' ),
				'top_icon'           => '<i class="fa fa-desktop"></i>',
				'right_icon'         => '<i class="fa fa-laptop"></i>',
				'bottom_icon'        => '<i class="fa fa-tablet"></i>',
				'left_icon'          => '<i class="fa fa-mobile"></i>',
				'top_placeholder'    => 'height',
				'right_placeholder'  => 'height',
				'bottom_placeholder' => 'height',
				'left_placeholder'   => 'height',
				'lg_desktop'         => true,
				'color'              => false,
				'styles'             => array(
					'max-height',
					'height',
				),
				'default'            => array(
					'lg_desktop' => 700,
					'top'        => 600,
					'right'      => 500,
					'bottom'     => 400,
					'left'       => 300,
					'style'      => 'max-height',
					'unit'       => 'px',
				),
				'dependency'         => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel,video-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_img_width_auto',
				'type'       => 'checkbox',
				'title'      => __( 'Image Width Auto', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Check to make image width auto.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_layout|show_image', '==|==', 'thumbnails-slider|true', true ),
			),
			array(
				'id'         => 'wpcp_product_image_border',
				'type'       => 'border',
				'title'      => __( 'Image Border', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set border for the product image.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/image-border.svg" alt="Image Border"></div><div class="sp_wpcp-info-label">' . __( 'Image Border', 'wp-carousel-pro' ) . '</div>',
				'all'        => true,
				'default'    => array(
					'all'         => '0',
					'style'       => 'solid',
					'color'       => '#dddddd',
					'hover-color' => '#dddddd',
				),
				'dependency' => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel|true', true ),
			),

			array(
				'id'         => '_variable_width',
				'type'       => 'switcher',
				'title'      => __( 'Variable Width', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable/Disable variable width. Number of column(s) depends on image width.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/variable-width.svg" alt="Variable Width"></div><div class="sp_wpcp-info-label">' . __( 'Variable Width', 'wp-carousel-pro' ) . '</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-enable-the-variable-width/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/variable-width/" target="_blank">Live Demo</a>',
				'default'    => false,
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'dependency' => array( 'wpcp_carousel_type|wpcp_carousel_orientation|wpcp_layout', '!=|!=|==', 'content-carousel|vertical|carousel', true ),
			),
			array(
				'id'         => 'wpcp_hide_product_without_img',
				'type'       => 'checkbox',
				'title'      => __( 'Hide Product without Thumbnail', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Hide products if featured image is not existed.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type|show_image', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => '_image_light_box',
				'type'       => 'switcher',
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'title'      => __( 'Lightbox', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable/Disable lightbox for the image.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type|show_image', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_lb_overlay_color',
				'type'       => 'color',
				'title'      => __( 'Lightbox Overlay Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set lightbox overlay color.', 'wp-carousel-pro' ),
				'default'    => '#0b0b0b',
				'dependency' => array( 'wpcp_carousel_type|show_image|_image_light_box', '==|==|==', 'product-carousel|true|true', true ),
			),
			array(
				'id'         => 'wpcp_image_lazy_load',
				'type'       => 'switcher',
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'title'      => __( 'Lazy Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable/Disable images lazy loading.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_mode|wpcp_carousel_type|show_image', '!=|any|==', 'ticker|image-carousel,post-carousel,product-carousel,video-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_image_zoom',
				'type'       => 'select',
				'title'      => __( 'Zoom', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a zoom effect on hover the image.', 'wp-carousel-pro' ),
				'title_help' => __( '<div class="sp_wpcp-info-label">Zoom</div><div class="sp_wpcp-short-content">This feature lets you choose a specific zoom effect when hovering over an image for an engaging experience.</div><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/post-carousel-zoom-image-modes/" target="_blank">Live Demo</a>', 'wp-carousel-pro' ),
				'options'    => array(
					''         => __( 'None', 'wp-carousel-pro' ),
					'zoom_in'  => __( 'Zoom In', 'wp-carousel-pro' ),
					'zoom_out' => __( 'Zoom Out', 'wp-carousel-pro' ),
				),
				'default'    => '',
				'class'      => 'chosen',
				'dependency' => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_image_gray_scale',
				'type'       => 'select',
				'title'      => __( 'Image Mode', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a mode for images.', 'wp-carousel-pro' ),
				'desc'       => __( 'Custom colors only apply to PNG files.', 'wp-carousel-pro' ),
				'options'    => array(
					''                         => __( 'Original', 'wp-carousel-pro' ),
					'gray_and_normal_on_hover' => __( 'Grayscale and original on hover', 'wp-carousel-pro' ),
					'gray_on_hover'            => __( 'Grayscale on hover', 'wp-carousel-pro' ),
					'always_gray'              => __( 'Always grayscale', 'wp-carousel-pro' ),
					'custom_color'             => __( 'Custom color', 'wp-carousel-pro' ),
				),
				'default'    => '',
				'class'      => 'chosen wpcp_image_mode',
				'dependency' => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_image_custom_color',
				'type'       => 'image_color',
				'title'      => __( 'Image Custom Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a custom color for images.', 'wp-carousel-pro' ),
				'options'    => array(
					'color'       => __( 'Color', 'wp-carousel-pro' ),
					'color_hover' => __( 'Hover', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color'       => '#aaaaaa',
					'color_hover' => '#999999',
				),
				'dependency' => array( 'wpcp_image_gray_scale', '==', 'custom_color', true ),
			),
			array(
				'id'         => 'wpcp_watermark',
				'class'      => 'wpcp_watermark',
				'type'       => 'switcher',
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'title'      => __( 'Watermark', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable/Disable watermark for the image.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/watermark.svg" alt="Watermark"></div><div class="sp_wpcp-info-label">' . __( 'Watermark', 'wp-carousel-pro' ) . '</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-configure-the-watermark/" target="_blank">Open Docs</a><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/watermark-protection/" target="_blank">Live Demo</a>',
				'desc'       => __( '<a href="' . esc_url( $single_page_link ) . '" target="_blank">Set watermark image→</a>', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'image-carousel', true ),
			),
			array(
				'id'         => 'wpcp_img_protection',
				'type'       => 'switcher',
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'title'      => __( 'Image Protection', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Enable to protect image downloading from right-click.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'image-carousel', true ),
			),
			array(
				'id'         => '_image_title_attr',
				'type'       => 'switcher',
				'title'      => __( 'Image Title Attribute', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide image title attribute.', 'wp-carousel-pro' ),
				'default'    => false,
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'dependency' => array( 'wpcp_carousel_type|show_image', 'any|==', 'image-carousel,post-carousel,product-carousel|true', true ),
			),

		), // End of fields array.
	)
); // Image settings section end.
