<?php
/**
 * Metabox config file.
 *
 * @link       https://shapedplugin.com
 * @since      3.0.0
 *
 * @package    WP_Carousel_Pro
 * @subpackage WP_Carousel_Pro/admin/views
 */

use ShapedPlugin\WPCarouselPro\Admin\views\sp_framework\classes\SP_WPCP_Framework;

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.
//
// Style settings section begin.
//
SP_WPCP_Framework::createSection(
	$wpcp_carousel_shortcode_settings,
	array(
		'title'  => __( 'Style Settings', 'wp-carousel-pro' ),
		'icon'   => 'fa fa-paint-brush',
		'fields' => array(
			array(
				'id'         => 'section_title',
				'type'       => 'switcher',
				'title'      => __( 'Section Title', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide the section title.', 'wp-carousel-pro' ),
				'default'    => false,
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 75,
			),
			array(
				'id'              => 'wpcp_content_carousel_height',
				'type'            => 'dimensions_advanced',
				'title'           => __( 'Slide Height', 'wp-carousel-pro' ),
				'subtitle'        => __( 'Set height for the slides in pixel.', 'wp-carousel-pro' ),
				'top_icon'        => '<i class="fa fa-arrows-v"></i>',
				'top_placeholder' => 'height',
				'right'           => false,
				'bottom'          => false,
				'left'            => false,
				'color'           => false,
				'styles'          => array(
					'min-height',
					'height',
				),
				'default'         => array(
					'top'   => 300,
					'style' => 'min-height',
					'unit'  => 'px',
				),
				'dependency'      => array( 'wpcp_carousel_type', '==', 'content-carousel', true ),
			),
			array(
				'id'         => 'wpcp_content_style',
				'class'      => 'wpcp_content_style',
				'type'       => 'image_select',
				'title'      => __( 'Items Style', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select an item style for the title, description, meta etc.', 'wp-carousel-pro' ),
				'options'    => array(
					'default'          => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/default/default-bottom.svg',
						'text'  => __( 'Default', 'wp-carousel-pro' ),
					),
					'with_overlay'     => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/overlay/overlay-full.svg',
						'text'  => __( 'Overlay', 'wp-carousel-pro' ),
					),
					'caption_full'     => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-full/content-style-bottom.svg',
						'text'  => __( 'Caption Full', 'wp-carousel-pro' ),
					),
					'caption_partial'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-style-bottom-left.svg',
						'text'  => __( 'Caption Partial', 'wp-carousel-pro' ),
					),
					'content_diagonal' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/diagonal/content-style-bottom-left.svg',
						'text'  => __( 'Diagonal', 'wp-carousel-pro' ),
					),
					'content_box'      => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-bottom.svg',
						'text'  => __( 'Content Box', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'default',
				'dependency' => array( 'wpcp_carousel_type', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_detail_position',
				'class'      => 'wpcp_content_position default_content',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for the content.', 'wp-carousel-pro' ),
				'options'    => array(
					'bottom'   => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/default/default-bottom.svg',
						'text'  => __( 'Bottom', 'wp-carousel-pro' ),
					),
					'top'      => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/default/default-top.svg',
						'text'  => __( 'Top', 'wp-carousel-pro' ),
					),
					'on_right' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/default/default-right.svg',
						'text'  => __( 'Right', 'wp-carousel-pro' ),
					),
					'on_left'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/default/default-left.svg',
						'text'  => __( 'Left', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==|==', 'image-carousel,post-carousel,product-carousel,external-carousel|default', true ),
			),
			array(
				'id'         => 'wpcp_overlay_position',
				'class'      => 'wpcp_content_position overlay_style',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for content', 'wp-carousel-pro' ),
				'inline'     => true,
				'options'    => array(
					'full_covered' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/overlay/overlay-full.svg',
						'text'  => __( 'Full', 'wp-carousel-pro' ),
					),
					'left'         => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/overlay/overlay-left.svg',
						'text'  => __( 'Left', 'wp-carousel-pro' ),
					),
					'right'        => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/overlay/overlay-right.svg',
						'text'  => __( 'Right', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'full_covered',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel|with_overlay', true ),
			),
			array(
				'id'         => 'wpcp_caption_full',
				'class'      => 'wpcp_content_position caption_full',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for content', 'wp-carousel-pro' ),
				'inline'     => true,
				'options'    => array(
					'bottom' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-full/content-style-bottom.svg',
						'text'  => __( 'Bottom', 'wp-carousel-pro' ),
					),
					'center' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-full/content-style-center.svg',
						'text'  => __( 'Center', 'wp-carousel-pro' ),
					),
					'top'    => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-full/content-style-top.svg',
						'text'  => __( 'Top', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel|caption_full', true ),
			),
			array(
				'id'         => 'wpcp_caption_partial',
				'class'      => 'wpcp_content_position caption_partial',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for content', 'wp-carousel-pro' ),
				'inline'     => true,
				'options'    => array(
					'bottom_left'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-style-bottom-left.svg',
						'text'  => __( 'Bottom-Left', 'wp-carousel-pro' ),
					),
					'top_left'     => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-style-top-left.svg',
						'text'  => __( 'Top-Left', 'wp-carousel-pro' ),
					),
					'bottom_right' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-style-bottom-right.svg',
						'text'  => __( 'Bottom-right', 'wp-carousel-pro' ),
					),
					'top_right'    => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-style-top-right.svg',
						'text'  => __( 'Top-Right', 'wp-carousel-pro' ),
					),
					'moving'       => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/caption-partial/content-moving.svg',
						'text'  => __( 'Moving', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom_left',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel|caption_partial', true ),
			),
			array(
				'id'         => 'wpcp_caption_diagonal',
				'class'      => 'wpcp_content_position caption_diagonal',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for content', 'wp-carousel-pro' ),
				'inline'     => true,
				'options'    => array(
					'bottom_left'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/diagonal/content-style-bottom-left.svg',
						'text'  => __( 'Bottom-Left', 'wp-carousel-pro' ),
					),
					'top_left'     => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/diagonal/content-style-top-left.svg',
						'text'  => __( 'Top-Left', 'wp-carousel-pro' ),
					),
					'bottom_right' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/diagonal/content-style-bottom-right.svg',
						'text'  => __( 'Bottom-Right', 'wp-carousel-pro' ),
					),
					'top_right'    => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/diagonal/content-style-top-right.svg',
						'text'  => __( 'Top-Right', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom_left',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel|content_diagonal', true ),
			),
			array(
				'id'         => 'wpcp_content_box',
				'class'      => 'wpcp_content_position content_box',
				'type'       => 'image_select',
				'title'      => __( 'Content Position', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a position for the content', 'wp-carousel-pro' ),
				'inline'     => true,
				'options'    => array(
					'bottom' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-bottom.svg',
						'text'  => __( 'Bottom', 'wp-carousel-pro' ),
					),
					'top'    => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-top.svg',
						'text'  => __( 'Top', 'wp-carousel-pro' ),
					),
					'left'   => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-left.svg',
						'text'  => __( 'Left', 'wp-carousel-pro' ),
					),
					'right'  => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-right.svg',
						'text'  => __( 'Right', 'wp-carousel-pro' ),
					),
					'center' => array(
						'image' => WPCAROUSEL_URL . 'Admin/img/content-box/content-box-center.svg',
						'text'  => __( 'Center', 'wp-carousel-pro' ),
					),
				),
				'default'    => 'bottom',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|==', 'image-carousel,post-carousel,product-carousel,external-carousel|content_box', true ),
			),

			array(
				'id'         => 'item_same_height',
				'type'       => 'switcher',
				'title'      => __( 'Enable Equal Height', 'wp-carousel-pro' ),
				'text_on'    => __( 'Enabled', 'wp-carousel-pro' ),
				'text_off'   => __( 'Disabled', 'wp-carousel-pro' ),
				'text_width' => 95,
				'subtitle'   => __( 'Enable to make all items or slides equal to the tallest one.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/equal-height.svg" alt="Equal Height"></div><div class="sp_wpcp-info-label">' . __( 'Equal Height', 'wp-carousel-pro' ) . '</div><a class="sp_wpcp-open-docs" href="https://docs.shapedplugin.com/docs/wordpress-carousel-pro/configurations/how-to-enable-equal-height/" target="_blank">Open Docs</a>',
				'default'    => false,
				'dependency' => array( 'wpcp_layout|wpcp_content_style', 'not-any|==', 'thumbnails-slider,justified,masonry,tiles|default', true ),
			),
			array(
				'id'          => 'wpcp_content_box_border',
				'type'        => 'border',
				'class'       => 'wpcp_content_box_border',
				'title'       => __( 'Content Box Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set content box border for the items.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => false,
				'radius'      => true,
				'default'     => array(
					'all'    => '0',
					'style'  => 'solid',
					'color'  => '#dddddd',
					'radius' => '2',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_content_style', 'any|any', 'image-carousel,post-carousel,product-carousel|caption_partial,content_box', true ),
			),
			// Box Shadow.
			array(
				'id'         => 'wpcp_show_content_box_shadow',
				'type'       => 'checkbox',
				'class'      => 'wpcp_show_content_box_shadow',
				'title'      => __( 'Content Box-Shadow', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Check to enable content box-shadow for the item.', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|any', 'image-carousel,post-carousel,product-carousel|caption_partial,content_box', true ),
			),
			array(
				'id'          => 'wpcp_content_box_shadow',
				'type'        => 'box_shadow',
				'class'       => 'wpcp_content_box_shadow',
				'title'       => __( 'Content Box-Shadow Values', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set content box-shadow property values for the item.', 'wp-carousel-pro' ),
				'style'       => true,
				'hover_color' => true,
				'default'     => array(
					'vertical'    => '0',
					'horizontal'  => '0',
					'blur'        => '10',
					'spread'      => '0',
					'style'       => 'outset',
					'color'       => '#dddddd',
					'hover_color' => '#dddddd',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_show_content_box_shadow', 'any|any|==', 'image-carousel,post-carousel,product-carousel|caption_partial,content_box|true', true ),
			),

			array(
				'id'         => 'wpcp_content_vertical_alignment',
				'type'       => 'button_set',
				'class'      => 'wpcp_content_vertical_alignment',
				'title'      => __( 'Vertical Alignment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select a vertical alignment for the content.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/content-vertical-alignment.svg" alt="Content Vertical Alignment"></div><div class="sp_wpcp-info-label">' . __( 'Content Vertical Alignment', 'wp-carousel-pro' ) . '</div>',
				'options'    => array(
					'flex-start' => __( 'Top', 'wp-carousel-pro' ),
					'center'     => __( 'Middle', 'wp-carousel-pro' ),
					'flex-end'   => __( 'Bottom', 'wp-carousel-pro' ),
				),
				'default'    => 'center',
				'dependency' => array( 'wpcp_layout|wpcp_content_style|item_same_height', 'not-any|any|==', 'thumbnails-slider,justified,masonry|with_overlay,default|false', true ),
			),

			array(
				'id'         => 'wpcp_content_box_size',
				'class'      => 'wpcp_content_box_size',
				'type'       => 'spinner',
				'title'      => __( 'Content Box Size', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set content box size.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/content-box-size.svg" alt="Content Box Size"></div><div class="sp_wpcp-info-label">' . __( 'Content Box Size', 'wp-carousel-pro' ) . '</div><a class="sp_wpcp-open-live-demo" href="https://wordpresscarousel.com/content-box-size/" target="_blank">Live Demo</a>',
				'default'    => 50,
				'unit'       => '%',
				'dependency' => array( 'wpcp_layout|item_same_height|wpcp_content_style', 'not-any|==|==', 'thumbnails-slider,justified,masonry|false|with_overlay', true ),
			),
			array(
				'id'         => 'wpcp_overlay_visibility',
				'type'       => 'button_set',
				'class'      => 'wpcp_overlay_visibility',
				'title'      => __( 'Overlay Content Visibility', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set visibility for the overlay content.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/overlay-content-visibility.svg" alt="Overlay Content Visibility"></div><div class="sp_wpcp-info-label">' . __( 'Overlay Content Visibility', 'wp-carousel-pro' ) . '</div>',
				'options'    => array(
					'always'   => __( 'Always', 'wp-carousel-pro' ),
					'on_hover' => __( 'On Hover', 'wp-carousel-pro' ),
				),
				'radio'      => true,
				'default'    => 'always',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|not-any', 'image-carousel,post-carousel,product-carousel|default,content_box,with_overlay', true ),
			),
			array(
				'id'         => 'wpcp_overlay_animation',
				'type'       => 'select',
				'class'      => 'wpcp_overlay_animation',
				'title'      => __( 'Animation Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select an animation type for the overlay content on hover.', 'wp-carousel-pro' ),
				'options'    => array(
					'none'         => __( 'None', 'wp-carousel-pro' ),
					'fadeIn'       => __( 'fadeIn', 'wp-carousel-pro' ),
					'fadeInDown'   => __( 'fadeInDown', 'wp-carousel-pro' ),
					'fadeInRight'  => __( 'fadeInRight', 'wp-carousel-pro' ),
					'fadeInLeft'   => __( 'fadeInLeft', 'wp-carousel-pro' ),
					'fadeInUp'     => __( 'fadeInUp', 'wp-carousel-pro' ),
					'flipInX'      => __( 'flipInX', 'wp-carousel-pro' ),
					'flipInY'      => __( 'flipInY', 'wp-carousel-pro' ),
					'slideInUp'    => __( 'slideInUp', 'wp-carousel-pro' ),
					'slideInDown'  => __( 'slideInDown', 'wp-carousel-pro' ),
					'zoomIn'       => __( 'zoomIn', 'wp-carousel-pro' ),
					'zoomInDown'   => __( 'zoomInDown', 'wp-carousel-pro' ),
					'jackInTheBox' => __( 'jackInTheBox', 'wp-carousel-pro' ),
					'rollIn'       => __( 'rollIn', 'wp-carousel-pro' ),
				),
				'default'    => 'none',
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_overlay_visibility', 'any|not-any|==', 'image-carousel,post-carousel,product-carousel|default,content_box,caption_partial|on_hover', true ),
			),
			array(
				'id'         => 'wpcp_overlay_color_type',
				'type'       => 'button_set',
				'class'      => 'wpcp_overlay_color_type',
				'title'      => __( 'Overlay Background Color Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select overlay background color type.', 'wp-carousel-pro' ),
				'options'    => array(
					'solid'    => __( 'Solid', 'wp-carousel-pro' ),
					'gradient' => __( 'Gradient', 'wp-carousel-pro' ),
				),
				'default'    => 'solid',
				'dependency' => array( 'wpcp_layout|item_same_height|wpcp_content_style', 'not-any|==|not-any', 'thumbnails-slider,justified,masonry|false|default,content_box,caption_partial', true ),
			),
			array(
				'id'         => 'wpcp_overlay_bg',
				'type'       => 'color',
				'class'      => 'wpcp_overlay_bg',
				'title'      => __( 'Solid Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a color for the overlay background.', 'wp-carousel-pro' ),
				'default'    => 'rgba(0,0,0,0.55)',
				'rgba'       => true,
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_overlay_color_type', 'any|not-any|==', 'image-carousel,post-carousel,product-carousel|default,content_box,caption_partial|solid', true ),
			),
			array(
				'id'                    => 'wpcp_bg_gradient_color',
				'type'                  => 'background',
				'class'                 => 'wpcp_bg_gradient_color',
				'title'                 => __( 'Gradient Color', 'wp-carousel-pro' ),
				'subtitle'              => __( 'Set gradient color for the tab title background.', 'wp-carousel-pro' ),
				'background_gradient'   => true,
				'background_color'      => true,
				'background_image'      => false,
				'background_position'   => false,
				'background_repeat'     => false,
				'background_attachment' => false,
				'background_size'       => false,
				'default'               => array(
					'background-color'              => '#004054bd',
					'background-gradient-color'     => '#23b7edb5',
					'background-gradient-direction' => '135deg',
				),
				'dependency'            => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_overlay_color_type', 'any|not-any|==', 'image-carousel,post-carousel,product-carousel|default,content_box,caption_partial|gradient', true ),
			),
			array(
				'id'         => 'wpcp_content_box_color_type',
				'type'       => 'button_set',
				'class'      => 'wpcp_content_box_color_type',
				'title'      => __( 'Content Box Background Color Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select content box background color type.', 'wp-carousel-pro' ),
				'options'    => array(
					'solid'    => __( 'Solid', 'wp-carousel-pro' ),
					'gradient' => __( 'Gradient', 'wp-carousel-pro' ),
				),
				'default'    => 'solid',
				'dependency' => array( 'wpcp_layout|wpcp_content_style|item_same_height|wpcp_caption_partial', 'not-any|any|==|==', 'thumbnails-slider,justified,masonry|caption_partial,content_box|false|moving', true ),
			),
			array(
				'id'         => 'wpcp_content_overlay_bg',
				'type'       => 'color',
				'class'      => 'wpcp_content_overlay_bg',
				'title'      => __( 'Content Solid Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a color for the overlay content background.', 'wp-carousel-pro' ),
				'default'    => 'rgba(0,0,0,0.55)',
				'rgba'       => true,
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_content_box_color_type|wpcp_caption_partial', 'any|any|==|==', 'image-carousel,post-carousel,product-carousel|caption_partial,content_box|solid|moving', true ),
			),
			array(
				'id'                    => 'wpcp_content_bg_gradient_color',
				'type'                  => 'background',
				'class'                 => 'wpcp_content_bg_gradient_color',
				'title'                 => __( 'Content Gradient Color', 'wp-carousel-pro' ),
				'subtitle'              => __( 'Set gradient color for the tab content background.', 'wp-carousel-pro' ),
				'background_gradient'   => true,
				'background_color'      => true,
				'background_image'      => false,
				'background_position'   => false,
				'background_repeat'     => false,
				'background_attachment' => false,
				'background_size'       => false,
				'default'               => array(
					'background-color'              => '#004054bd',
					'background-gradient-color'     => '#23b7edb5',
					'background-gradient-direction' => '135deg',
				),
				'dependency'            => array( 'wpcp_carousel_type|wpcp_content_style|wpcp_content_box_color_type|wpcp_caption_partial', 'any|any|==|==', 'image-carousel,post-carousel,product-carousel|caption_partial,content_box|gradient|moving', true ),
			),
			array(
				'id'         => 'wpcp_image_vertical_alignment',
				'type'       => 'button_set',
				'class'      => 'wpcp_image_vertical_alignment',
				'title'      => __( 'Items Vertical Alignment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select a vertical alignment for the items.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/slider-vertical-alignment.svg" alt="Slider Vertical Alignment"></div><div class="sp_wpcp-info-label">' . __( 'Slider Vertical Alignment', 'wp-carousel-pro' ) . '</div>',
				'options'    => array(
					'flex-start' => __( 'Top', 'wp-carousel-pro' ),
					'center'     => __( 'Middle', 'wp-carousel-pro' ),
					'flex-end'   => __( 'Bottom', 'wp-carousel-pro' ),
				),
				'default'    => 'center',
				'dependency' => array( 'wpcp_layout|item_same_height', 'not-any|==', 'thumbnails-slider,justified,masonry|false', true ),
			),
			array(
				'id'          => 'wpcp_slide_border',
				'type'        => 'border',
				'title'       => __( 'Items Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set border for the items.', 'wp-carousel-pro' ),
				'title_help'  => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/slider-border.svg" alt="Items Border"></div><div class="sp_wpcp-info-label">' . __( 'Items Border', 'wp-carousel-pro' ) . '</div>',
				'all'         => true,
				'hover-color' => false,
				'radius'      => true,
				'default'     => array(
					'all'    => '1',
					'style'  => 'solid',
					'color'  => '#dddddd',
					'radius' => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type', 'any', 'image-carousel,post-carousel,product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_slide_inner_padding',
				'type'       => 'spacing',
				'title'      => __( 'Items Inner Padding', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set an inner padding for the items.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/slider-inner-padding.svg" alt="Items Inner Padding"></div><div class="sp_wpcp-info-label">' . __( 'Items Inner Padding', 'wp-carousel-pro' ) . '</div>',
				'style'      => false,
				'color'      => false,
				'all'        => false,
				'units'      => array( 'px' ),
				'default'    => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'attributes' => array(
					'min' => 0,
				),
				'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,post-carousel,product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_content_inner_padding',
				'type'       => 'spacing',
				'class'      => 'wpcp_content_inner_padding',
				'title'      => __( 'Content Padding', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set content inner padding of the item.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/content-padding.svg" alt="Content Padding"></div><div class="sp_wpcp-info-label">' . __( 'Content Padding', 'wp-carousel-pro' ) . '</div>',
				'style'      => false,
				'color'      => false,
				'all'        => false,
				'units'      => array( 'px' ),
				'default'    => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'attributes' => array(
					'min' => 0,
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|any', 'image-carousel,post-carousel,product-carousel|default,with_overlay,caption_full,caption_partial,content_diagonal', true ),
			),
			array(
				'id'         => 'wpcp_content_box_padding',
				'type'       => 'spacing',
				'class'      => 'wpcp_content_box_padding',
				'title'      => __( 'Content Box Padding', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set content inner padding of the slide. Default value is 0.', 'wp-carousel-pro' ),
				'title_help' => '<div class="sp_wpcp-img-tag"><img src="' . WPCAROUSEL_URL . 'Admin/img/help-visuals/content-box-padding.svg" alt="Content Box Padding"></div><div class="sp_wpcp-info-label">' . __( 'Content Box Padding', 'wp-carousel-pro' ) . '</div>',
				'style'      => false,
				'color'      => false,
				'all'        => false,
				'units'      => array( 'px' ),
				'default'    => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'attributes' => array(
					'min' => 0,
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_content_style', 'any|any', 'image-carousel,post-carousel,product-carousel|with_overlay,content_box', true ),
			),
			array(
				'id'         => 'wpcp_slide_background',
				'type'       => 'color',
				'title'      => __( 'Items Background Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set a background color for the items.', 'wp-carousel-pro' ),
				'default'    => 'transparent',
				'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,post-carousel,product-carousel,video-carousel', true ),
			),
			// Box Shadow.
			array(
				'id'       => 'wpcp_show_box_shadow',
				'type'     => 'checkbox',
				'title'    => __( 'Items Box-Shadow', 'wp-carousel-pro' ),
				'subtitle' => __( 'Check to enable box-shadow for the items.', 'wp-carousel-pro' ),
			),
			array(
				'id'          => 'wpcp_box_shadow',
				'type'        => 'box_shadow',
				'title'       => __( 'Box-Shadow Values', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set box-shadow property values for the item.', 'wp-carousel-pro' ),
				'style'       => true,
				'hover_color' => true,
				'default'     => array(
					'vertical'    => '0',
					'horizontal'  => '0',
					'blur'        => '10',
					'spread'      => '0',
					'style'       => 'outset',
					'color'       => '#dddddd',
					'hover_color' => '#dddddd',
				),
				'dependency'  => array( 'wpcp_show_box_shadow', '==', 'true', true ),
			),

			array(
				'id'         => 'wpcp_video_icon_size',
				'type'       => 'spinner',
				'title'      => __( 'Video Icon Size', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set size for video icon.', 'wp-carousel-pro' ),
				'default'    => 40,
				'unit'       => 'px',
				'dependency' => array( 'wpcp_carousel_type', '==', 'video-carousel', true ),
			),
			array(
				'id'         => 'wpcp_video_icon_color',
				'type'       => 'color',
				'title'      => __( 'Video Icon Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Used as video icon color.', 'wp-carousel-pro' ),
				'default'    => '#fff',
				'dependency' => array( 'wpcp_carousel_type', '==', 'video-carousel', true ),
			),
			// Post Settings.
			array(
				'id'         => 'wpcp_feed_title',
				'type'       => 'switcher',
				'title'      => __( 'Post Title', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post title.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==|==', 'external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_feed_content_show',
				'type'       => 'switcher',
				'title'      => __( 'Feed Content', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide feed content.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==|==', 'external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_feed_content_chars_limit',
				'type'       => 'spinner',
				'title'      => __( 'Length', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Leave empty to show full feed content.', 'wp-carousel-pro' ),
				'default'    => 100,
				'min'        => 0,
				'unit'       => 'Letters',
				'dependency' => array( 'wpcp_carousel_type|wpcp_feed_content_show', '==|==|==', 'external-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_feed_readmore_button_show',
				'type'       => 'switcher',
				'title'      => __( 'Read More Button', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide content read more button.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_feed_readmore_text',
				'type'       => 'text',
				'title'      => __( 'Read More Button Label', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Change the read more button label text.', 'wp-carousel-pro' ),
				'default'    => 'Read More',
				'dependency' => array( 'wpcp_carousel_type|wpcp_feed_readmore_button_show', '==|==', 'external-carousel|true', true ),
			),
			array(
				'id'          => 'wpcp_feed_readmore_border',
				'type'        => 'border',
				'title'       => __( 'Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set border for the readmore button.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => true,
				'radius'      => true,
				'default'     => array(
					'all'         => '1',
					'style'       => 'solid',
					'color'       => '#257F87',
					'hover-color' => '#1f5c5d',
					'radius'      => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_feed_readmore_button_show', '==|==', 'external-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_feed_readmore_color_set',
				'type'       => 'color_group',
				'title'      => __( 'Read More Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the read more button.', 'wp-carousel-pro' ),
				'options'    => array(
					'color1' => __( 'Color', 'wp-carousel-pro' ),
					'color2' => __( 'Hover Color', 'wp-carousel-pro' ),
					'color3' => __( 'Background', 'wp-carousel-pro' ),
					'color4' => __( 'Hover Background', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#fff',
					'color2' => '#fff',
					'color3' => '#257F87',
					'color4' => '#1f5c5d',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_feed_readmore_button_show', '==|==', 'external-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_post_title',
				'type'       => 'switcher',
				'title'      => __( 'Post Title', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post title.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_title_chars_limit',
				'type'       => 'spinner',
				'title'      => __( 'Length', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Leave empty to show full post title.', 'wp-carousel-pro' ),
				'default'    => '',
				'min'        => 0,
				'unit'       => 'Letters',
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_title', '==|==', 'post-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_image_caption',
				'type'       => 'switcher',
				'title'      => __( 'Caption', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide caption for the image.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'image-carousel', true ),
			),
			array(
				'id'         => 'wpcp_image_desc',
				'type'       => 'switcher',
				'title'      => __( 'Description', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide description for image.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,video-carousel', true ),
			),
			array(
				'id'         => 'img_desc_display_type',
				'type'       => 'button_set',
				'title'      => __( 'Display Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose the description display type.', 'wp-carousel-pro' ),
				'options'    => array(
					'full'  => __( 'Full', 'wp-carousel-pro' ),
					'limit' => __( 'Limit', 'wp-carousel-pro' ),
				),
				'default'    => 'full',
				'dependency' => array( 'wpcp_carousel_type|wpcp_image_desc', '==|==', 'image-carousel|true', true ),
			),
			array(
				'id'         => 'img_desc_word_limit',
				'type'       => 'spinner',
				'title'      => __( 'Words Limit', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set description words limit.', 'wp-carousel-pro' ),
				'default'    => '30',
				'min'        => 0,
				'dependency' => array( 'wpcp_carousel_type|wpcp_image_desc|img_desc_display_type', '==|==|==', 'image-carousel|true|limit', true ),
			),
			array(
				'id'         => 'img_desc_read_more',
				'type'       => 'switcher',
				'title'      => __( 'Read More Button', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide description read more button.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type|wpcp_image_desc|img_desc_display_type', '==|==|==', 'image-carousel|true|limit', true ),
			),
			array(
				'id'         => 'img_readmore_label',
				'type'       => 'text',
				'title'      => __( 'Read More Button Label', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Change the read more button label text.', 'wp-carousel-pro' ),
				'default'    => 'Read More',
				'dependency' => array( 'wpcp_carousel_type|wpcp_image_desc|img_desc_display_type|img_desc_read_more', '==|==|==|==', 'image-carousel|true|limit|true', true ),
			),
			array(
				'id'          => 'img_readmore_border',
				'type'        => 'border',
				'title'       => __( 'Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set description read more button text.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => true,
				'radius'      => true,
				'default'     => array(
					'all'         => '1',
					'style'       => 'solid',
					'color'       => '#257F87',
					'hover-color' => '#1f5c5d',
					'radius'      => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_image_desc|img_desc_display_type|img_desc_read_more', '==|==|==|==', 'image-carousel|true|limit|true', true ),
			),
			array(
				'id'         => 'img_readmore_color_set',
				'type'       => 'color_group',
				'title'      => __( 'Read More Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the read more button.', 'wp-carousel-pro' ),
				'options'    => array(
					'color1' => __( 'Label Color', 'wp-carousel-pro' ),
					'color2' => __( 'Hover Color', 'wp-carousel-pro' ),
					'color3' => __( 'Background', 'wp-carousel-pro' ),
					'color4' => __( 'Hover Background', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#fff',
					'color2' => '#fff',
					'color3' => '#257F87',
					'color4' => '#1f5c5d',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_image_desc|img_desc_display_type|img_desc_read_more', '==|==|==|==', 'image-carousel|true|limit|true', true ),
			),
			array(
				'id'         => 'wpcp_post_content_show',
				'type'       => 'switcher',
				'title'      => __( 'Post Content', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post content.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_content_type',
				'type'       => 'select',
				'title'      => __( 'Content Display Type', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Select a content display type.', 'wp-carousel-pro' ),
				'options'    => array(
					'excerpt'            => __( 'Excerpt', 'wp-carousel-pro' ),
					'content'            => __( 'Full Content', 'wp-carousel-pro' ),
					'content_with_limit' => __( 'Content with Limit', 'wp-carousel-pro' ),
				),
				'default'    => 'content_with_limit',
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_content_show', '==|==', 'post-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_post_content_words_limit',
				'type'       => 'spinner',
				'title'      => __( 'Post Content Words Limit', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set post content words limit. Default value is 30 words.', 'wp-carousel-pro' ),
				'default'    => 30,
				'min'        => 0,
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_content_show|wpcp_post_content_type', '==|==|==', 'post-carousel|true|content_with_limit', true ),
			),
			array(
				'id'         => 'wpcp_post_readmore_button_show',
				'class'      => 'wpcp_post_readmore_button_show',
				'type'       => 'switcher',
				'title'      => __( 'Read More Button', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide content read more button.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_post_content_type|wpcp_carousel_type', '!=|==', 'content|post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_readmore_text',
				'type'       => 'text',
				'title'      => __( 'Read More Button Label', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Change the read more button label text.', 'wp-carousel-pro' ),
				'default'    => 'Read More',
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_content_type|wpcp_post_readmore_button_show', '==|any|==', 'post-carousel|content_with_limit,excerpt|true', true ),
			),
			array(
				'id'          => 'wpcp_readmore_border',
				'type'        => 'border',
				'title'       => __( 'Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set border for the readmore button.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => true,
				'radius'      => true,
				'default'     => array(
					'all'         => '1',
					'style'       => 'solid',
					'color'       => '#257F87',
					'hover-color' => '#1f5c5d',
					'radius'      => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_post_content_type|wpcp_post_readmore_button_show', '==|any|==', 'post-carousel|content_with_limit,excerpt|true', true ),
			),
			array(
				'id'         => 'wpcp_readmore_color_set',
				'type'       => 'color_group',
				'title'      => __( 'Read More Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the read more button.', 'wp-carousel-pro' ),
				'options'    => array(
					'color1' => __( 'Label Color', 'wp-carousel-pro' ),
					'color2' => __( 'Hover Color', 'wp-carousel-pro' ),
					'color3' => __( 'Background', 'wp-carousel-pro' ),
					'color4' => __( 'Hover Background', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#fff',
					'color2' => '#fff',
					'color3' => '#257F87',
					'color4' => '#1f5c5d',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_content_type|wpcp_post_readmore_button_show', '==|any|==', 'post-carousel|content_with_limit,excerpt|true', true ),
			),
			array(
				'type'       => 'subheading',
				'content'    => __( 'Post Meta', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_category_show',
				'type'       => 'switcher',
				'title'      => __( 'Category', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post category name.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_author_show',
				'type'       => 'switcher',
				'title'      => __( 'Author', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post author name.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_date_show',
				'type'       => 'switcher',
				'title'      => __( 'Date', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post date.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_comment_show',
				'type'       => 'switcher',
				'title'      => __( 'Comment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post comment number.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_tags_show',
				'type'       => 'switcher',
				'title'      => __( 'Tag', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post tags.', 'wp-carousel-pro' ),
				'default'    => false,
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'type'       => 'subheading',
				'content'    => __( 'Social Share', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_social_show',
				'type'       => 'switcher',
				'title'      => __( 'Social Share', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide post social share.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'post-carousel', true ),
			),
			array(
				'id'          => 'wpcp_post_social_border',
				'type'        => 'border',
				'title'       => __( 'Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set border for the social button.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => true,
				'radius'      => true,
				'default'     => array(
					'all'         => '1',
					'style'       => 'solid',
					'color'       => '#257F87',
					'hover-color' => '#1f5c5d',
					'radius'      => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_post_social_show', '==|==', 'post-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_post_social_color',
				'type'       => 'color_group',
				'title'      => __( 'Social Button Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the social button.', 'wp-carousel-pro' ),
				'options'    => array(
					'color1' => __( 'Icon Color', 'wp-carousel-pro' ),
					'color2' => __( 'Icon Hover Color', 'wp-carousel-pro' ),
					'color3' => __( 'Background', 'wp-carousel-pro' ),
					'color4' => __( 'Hover Background', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#257F87',
					'color2' => '#fff',
					'color3' => '#fff',
					'color4' => '#1f5c5d',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_social_show', '==|==', 'post-carousel|true', true ),
			),
			array(
				'id'          => 'wpcp_post_social_margin',
				'type'        => 'spacing',
				'title'       => __( 'Margin', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set margin for social button.', 'wp-carousel-pro' ),
				'output_mode' => 'margin',
				'units'       => array( 'px' ),
				'min'         => '-200',
				'default'     => array(
					'top'    => '0',
					'right'  => '5',
					'bottom' => '0',
					'left'   => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_post_social_show', '==|==', 'post-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_post_social_alignment',
				'type'       => 'button_set',
				'title'      => __( 'Alignment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose social icon alignment.', 'wp-carousel-pro' ),
				'options'    => array(
					'left'   => '<i class="fa fa-align-left" title="Left"></i>',
					'center' => '<i class="fa fa-align-center" title="Center"></i>',
					'right'  => '<i class="fa fa-align-right" title="Right"></i>',
				),
				'default'    => 'center',
				'dependency' => array( 'wpcp_carousel_type|wpcp_post_social_show', '==|==', 'post-carousel|true', true ),
			),
			// Product.
			array(
				'type'       => 'subheading',
				'content'    => __( 'Product', 'wp-carousel-pro' ),
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_product_name',
				'type'       => 'switcher',
				'title'      => __( 'Product Name', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide product name.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_product_name_chars_limit',
				'type'       => 'spinner',
				'title'      => __( 'Length', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Leave empty to show full product name.', 'wp-carousel-pro' ),
				'default'    => '',
				'min'        => 0,
				'unit'       => 'Letters',
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_name', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_product_price',
				'type'       => 'switcher',
				'title'      => __( 'Product Price', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide product price.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_product_desc',
				'type'       => 'button_set',
				'title'      => __( 'Product Description', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Choose the description display type.', 'wp-carousel-pro' ),
				'options'    => array(
					'full'  => __( 'Full', 'wp-carousel-pro' ),
					'short' => __( 'Short', 'wp-carousel-pro' ),
					'hide'  => __( 'Hide', 'wp-carousel-pro' ),
				),
				'default'    => 'full',
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_product_desc_limit_number',
				'type'       => 'spinner',
				'title'      => __( 'Limit', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Leave empty to show full product description.', 'wp-carousel-pro' ),
				'default'    => '15',
				'min'        => 0,
				'unit'       => 'Words',
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_desc', '==|!=', 'product-carousel|hide', true ),
			),
			array(
				'id'         => 'wpcp_product_readmore_show',
				'type'       => 'switcher',
				'title'      => __( 'Read More', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide product content read more button.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_desc', '==|!=', 'product-carousel|hide', true ),
			),
			array(
				'id'         => 'wpcp_product_readmore_text',
				'type'       => 'text',
				'title'      => __( 'Read More Label', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Write text for the read more button.', 'wp-carousel-pro' ),
				'default'    => 'Read More',
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_desc|wpcp_product_readmore_show', '==|!=|==', 'product-carousel|hide|true', true ),
			),
			array(
				'id'         => 'wpcp_product_rating',
				'type'       => 'switcher',
				'title'      => __( 'Product Rating', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide product rating.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'         => 'wpcp_product_rating_star_color_set',
				'type'       => 'color_group',
				'title'      => __( 'Rating Star Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the rating stars.', 'wp-carousel-pro' ),
				'color1'     => true,
				'color2'     => true,
				'options'    => array(
					'color1' => __( 'Color', 'wp-carousel-pro' ),
					'color2' => __( 'Empty Color', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#ffb900',
					'color2' => '#cccccc',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_rating', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_product_rating_alignment',
				'type'       => 'button_set',
				'title'      => __( 'Rating Alignment', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set alignment for the product rating star.', 'wp-carousel-pro' ),
				'class'      => 'wpcp_rating_alignment',
				'options'    => array(
					'left'   => '<i class="fa fa-align-left" title="Left"></i>',
					'center' => '<i class="fa fa-align-center" title="Center"></i>',
					'right'  => '<i class="fa fa-align-right" title="Right"></i>',
				),
				'radio'      => true,
				'default'    => 'center',
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_rating', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_product_cart',
				'type'       => 'switcher',
				'title'      => __( 'Add to Cart Button', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Show/Hide add to cart button.', 'wp-carousel-pro' ),
				'text_on'    => __( 'Show', 'wp-carousel-pro' ),
				'text_off'   => __( 'Hide', 'wp-carousel-pro' ),
				'text_width' => 77,
				'default'    => true,
				'dependency' => array( 'wpcp_carousel_type', '==', 'product-carousel', true ),
			),
			array(
				'id'          => 'wpcp_add_to_cart_border',
				'type'        => 'border',
				'title'       => __( 'Add to Cart Border', 'wp-carousel-pro' ),
				'subtitle'    => __( 'Set border for the add to cart button.', 'wp-carousel-pro' ),
				'all'         => true,
				'hover-color' => true,
				'radius'      => true,
				'default'     => array(
					'all'         => '1',
					'style'       => 'solid',
					'color'       => '#d1d1d1',
					'hover-color' => '#d1d1d1',
					'radius'      => '0',
				),
				'dependency'  => array( 'wpcp_carousel_type|wpcp_product_cart', '==|==', 'product-carousel|true', true ),
			),
			array(
				'id'         => 'wpcp_add_to_cart_color_set',
				'type'       => 'color_group',
				'title'      => __( 'Add to Cart Color', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set color for the add to cart button.', 'wp-carousel-pro' ),
				'options'    => array(
					'color1' => __( 'Color', 'wp-carousel-pro' ),
					'color2' => __( 'Hover Color', 'wp-carousel-pro' ),
					'color3' => __( 'Background', 'wp-carousel-pro' ),
					'color4' => __( 'Hover Background', 'wp-carousel-pro' ),
				),
				'default'    => array(
					'color1' => '#545454',
					'color2' => '#fff',
					'color3' => '#ebebeb',
					'color4' => '#3f3f3f',
				),
				'dependency' => array( 'wpcp_carousel_type|wpcp_product_cart', '==|==', 'product-carousel|true', true ),
			),
		), // End of fields array.
	)
); // Style settings section end.
