<?php
/**
 * Metabox config file.
 *
 * @link       https://shapedplugin.com
 * @since      3.0.0
 *
 * @package    WP_Carousel_Pro
 * @subpackage WP_Carousel_Pro/admin/views
 */

use ShapedPlugin\WPCarouselPro\Admin\views\sp_framework\classes\SP_WPCP_Framework;
if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.
//
// Typography section begin.
//
SP_WPCP_Framework::createSection(
	$wpcp_carousel_shortcode_settings,
	array(
		'title'           => __( 'Typography', 'wp-carousel-pro' ),
		'icon'            => 'fa fa-font',
		'enqueue_webfont' => true,
		'fields'          => array(
			array(
				'id'       => 'section_title_font_load',
				'type'     => 'switcher',
				'title'    => __( 'Load Section Title Font', 'wp-carousel-pro' ),
				'subtitle' => __( 'On/Off google font for the section title.', 'wp-carousel-pro' ),
				'default'  => false,
			),
			array(
				'id'           => 'wpcp_section_title_typography',
				'type'         => 'typography',
				'title'        => __( 'Section Title Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set section title font properties.', 'wp-carousel-pro' ),
				'margin'       => true,
				'default'      => array(
					'color'          => '#444444',
					'font-family'    => '',
					'font-weight'    => '',
					'font-size'      => '24',
					'line-height'    => '28',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'text-transform' => 'none',
					'margin-top'     => '0',
					'margin-bottom'  => '30',
					'unit'           => 'px',
					'type'           => 'google',
					// 'unit'           => 'px',
				),
				'preview'      => 'always',
				'preview_text' => 'Section Title',
			),
			array(
				'id'         => 'wpcp_image_caption_font_load',
				'class'      => 'wpcp_image_caption_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Load Caption Font', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the image caption.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'image-carousel,external-carousel', true ),
			),
			array(
				'id'           => 'wpcp_image_caption_typography',
				'class'        => 'wpcp_image_caption_typography',
				'type'         => 'typography',
				'title'        => __( 'Caption Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set caption font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#333',
					'font-family'    => '',
					'font-weight'    => '',
					'font-size'      => '15',
					'line-height'    => '23',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'text-transform' => 'capitalize',
					'type'           => 'google',
				),
				'preview_text' => 'The image caption',
				'preview'      => 'always',
				'dependency'   => array( 'wpcp_carousel_type', 'any', 'image-carousel,external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_image_desc_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Load Description Font', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the image description.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', '==', 'image-carousel', true ),
			),
			array(
				'id'         => 'wpcp_image_desc_typography',
				'type'       => 'typography',
				'title'      => __( 'Description Font', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set description font properties.', 'wp-carousel-pro' ),
				'default'    => array(
					'color'          => '#333',
					'font-family'    => '',
					'font-weight'    => '',
					'font-style'     => 'normal',
					'font-size'      => '14',
					'line-height'    => '21',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview'    => 'always',
				'dependency' => array( 'wpcp_carousel_type', '==', 'image-carousel', true ),
			),
			// Post Typography.
			array(
				'id'         => 'wpcp_title_font_load',
				'class'      => 'wpcp_title_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Load Title Font', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the slide title.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),

			array(
				'id'           => 'wpcp_title_typography',
				'class'        => 'wpcp_title_typography',
				'type'         => 'typography',
				'title'        => __( 'Post Title Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set title font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#444',
					'hover_color'    => '#1f5c5d',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '18',
					'line-height'    => '26',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'text-transform' => 'capitalize',
					'type'           => 'google',
				),
				'hover_color'  => true,
				'preview_text' => 'The Post Title',
				'preview'      => 'always',
				'dependency'   => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),

			array(
				'id'         => 'wpcp_post_content_font_load',
				'class'      => 'wpcp_post_content_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Post Content Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for post the content.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_content_typography',
				'class'      => 'wpcp_post_content_typography',
				'type'       => 'typography',
				'title'      => __( 'Post Content Font', 'wp-carousel-pro' ),
				'subtitle'   => __( 'Set post content font properties.', 'wp-carousel-pro' ),
				'default'    => array(
					'color'          => '#444',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '24',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview'    => 'always',
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),

			array(
				'id'         => 'wpcp_post_cat_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Post Category Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the post category.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel', true ),
			),
			array(
				'id'           => 'wpcp_post_cat_typography',
				'type'         => 'typography',
				'title'        => __( 'Post Category Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set post category font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#22afba',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '18',
					'letter-spacing' => '0',
					'type'           => 'google',
				),
				'preview'      => 'always',
				'text_align'   => false,
				'preview_text' => 'The Category', // Replace preview text with any text you like.
				'dependency'   => array( 'wpcp_carousel_type', 'any', 'post-carousel', true ),
			),
			array(
				'id'         => 'wpcp_post_meta_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Post Meta Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the post meta.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type',
					'==',
					'post-carousel',
					true,
				),
			),
			array(
				'id'           => 'wpcp_post_meta_typography',
				'type'         => 'typography',
				'title'        => __( 'Post Meta Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set post meta font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#999',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '18',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview_text' => 'Post Meta', // Replace preview text with any text you like.
				'dependency'   => array(
					'wpcp_carousel_type',
					'==',
					'post-carousel',
					true,
				),
			),
			array(
				'id'         => 'wpcp_post_readmore_font_load',
				'class'      => 'wpcp_post_readmore_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Read More Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the read more.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),
			array(
				'id'           => 'wpcp_post_readmore_typography',
				'class'        => 'wpcp_post_readmore_typography',
				'type'         => 'typography',
				'title'        => __( 'Read More Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set read more font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '24',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview'      => 'always',
				'color'        => false,
				'preview_text' => 'Read more', // Replace preview text with any text you like.
				'dependency'   => array( 'wpcp_carousel_type', 'any', 'post-carousel,external-carousel', true ),
			),

			// Product Typography.
			array(
				'id'         => 'wpcp_product_name_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Product Name Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the product name.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type|wpcp_product_name',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'           => 'wpcp_product_name_typography',
				'type'         => 'typography',
				'title'        => __( 'Product Name Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set product name font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#444',
					'hover_color'    => '#555',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '15',
					'line-height'    => '23',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'hover_color'  => true,
				'preview_text' => 'Product Name', // Replace preview text.
				'dependency'   => array(
					'wpcp_carousel_type|wpcp_product_name',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'         => 'wpcp_product_desc_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Product Description Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the product description.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type|wpcp_product_desc',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'           => 'wpcp_product_desc_typography',
				'type'         => 'typography',
				'title'        => __( 'Product Description Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set product description font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#333',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '22',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview_text' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', // Replace preview text with any text you like.
				'dependency'   => array(
					'wpcp_carousel_type|wpcp_product_desc',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'         => 'wpcp_product_price_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Product Price Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the product price.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type|wpcp_product_price',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'           => 'wpcp_product_price_typography',
				'type'         => 'typography',
				'title'        => __( 'Product Price Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set product price font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#222',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '26',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'preview_text' => '$49.00', // Replace preview text with any text you like.
				'dependency'   => array(
					'wpcp_carousel_type|wpcp_product_price',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'         => 'wpcp_product_readmore_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Read More Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the read more.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type|wpcp_product_rating',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'           => 'wpcp_product_readmore_typography',
				'type'         => 'typography',
				'title'        => __( 'Read More Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set read more font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'color'          => '#e74c3c',
					'hover_color'    => '#e74c3c',
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '24',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'type'           => 'google',
				),
				'hover_color'  => true,
				'preview_text' => 'Read more', // Replace preview text with any text you like.
				'dependency'   => array(
					'wpcp_carousel_type|wpcp_product_rating',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'         => 'wpcp_product_cart_font_load',
				'type'       => 'switcher',
				'title'      => __( 'Product Add to Cart Font Load', 'wp-carousel-pro' ),
				'subtitle'   => __( 'On/Off google font for the product add to cart.', 'wp-carousel-pro' ),
				'default'    => false,
				'dependency' => array(
					'wpcp_carousel_type|wpcp_product_cart',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
			array(
				'id'           => 'wpcp_product_cart_typography',
				'type'         => 'typography',
				'title'        => __( 'Product Add To Cart Font', 'wp-carousel-pro' ),
				'subtitle'     => __( 'Set product add to cart font properties.', 'wp-carousel-pro' ),
				'default'      => array(
					'font-family'    => '',
					'font-style'     => '',
					'font-size'      => '14',
					'line-height'    => '21',
					'letter-spacing' => '0',
					'text-align'     => 'center',
					'text-transform' => 'uppercase',
					'type'           => 'google',
					'margin-top'     => '0',
					'margin-bottom'  => '10',
					'unit'           => 'px',
				),
				'color'        => false,
				'margin'       => true,
				'preview_text' => 'Add To Cart', // Replace preview text with any text you like.
				'dependency'   => array(
					'wpcp_carousel_type|wpcp_product_cart',
					'==|==',
					'product-carousel|true',
					true,
				),
			),
		), // End of fields array.
	)
); // Style settings section end.
