<?php
/**
 * Framework gallery field.
 *
 * @link       https://shapedplugin.com
 * @since      3.0.0
 *
 * @package    WP_Carousel_Pro
 * @subpackage WP_Carousel_Pro/admin/views
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

if ( ! class_exists( 'SP_WPCP_Framework_Field_gallery' ) ) {
	/**
	 *
	 * Field: gallery
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	class SP_WPCP_Framework_Field_gallery extends SP_WPCP_Framework_Fields {
		/**
		 * Field class constructor.
		 *
		 * @param array  $field The field type.
		 * @param string $value The values of the field.
		 * @param string $unique The unique ID for the field.
		 * @param string $where To where show the output CSS.
		 * @param string $parent The parent args.
		 */
		public function __construct( $field, $value = '', $unique = '', $where = '', $parent = '' ) {
			parent::__construct( $field, $value, $unique, $where, $parent );
		}


		/**
		 * Render
		 *
		 * @return void
		 */
		public function render() {

			$args = wp_parse_args(
				$this->field,
				array(
					'add_title'   => esc_html__( 'Add Gallery', 'wp-carousel-pro' ),
					'edit_title'  => esc_html__( 'Edit Gallery', 'wp-carousel-pro' ),
					'clear_title' => esc_html__( 'Clear', 'wp-carousel-pro' ),
				)
			);

			$hidden = ( empty( $this->value ) ) ? ' hidden' : '';

			echo wp_kses_post( $this->field_before() );
			// echo '<a href="#" class="button button-primary sp_wpcp-button"><i class="fa fa-plus-circle"></i>' . esc_html( $args['add_title'] ) . '</a>';
			echo '<a href="#" class="button button-primary sp_wpcp-button"> <img src="' . WPCAROUSEL_URL . 'Admin/img/add-image.svg" alt="">' . esc_html( $args['add_title'] ) . '</a>';

			echo '<ul class="sp-gallery-images">';
			if ( ! empty( $this->value ) ) {

				$values = explode( ',', $this->value );

				foreach ( $values as $id ) {
					$attachment = wp_get_attachment_image_src( $id, 'thumbnail' );
					if ( isset( $attachment[0] ) ) {
						echo '<li><img src="' . esc_url( $attachment[0] ) . '" /></li>';
					}
				}
			}
			echo '</ul>';
			echo '<ul> <li>';
			echo '<a href="#" class="button sp_wpcp-edit-gallery' . esc_attr( $hidden ) . '"><i class="fa fa-pencil-square-o"></i>' . esc_html( $args['edit_title'] ) . '</a>';
			echo '</ul></li>';
			echo '<ul> <li>';
			echo '<a href="#" class="button sp_wpcp-warning-primary sp_wpcp-clear-gallery' . esc_attr( $hidden ) . '"><i class="fa fa-trash"></i>' . esc_html( $args['clear_title'] ) . '</a>';
			echo '</ul></li>';
			echo '<input type="hidden" name="' . esc_attr( $this->field_name() ) . '" value="' . esc_attr( $this->value ) . '"' . $this->field_attributes() . '/>';// phpcs:ignore

			echo wp_kses_post( $this->field_after() );

		}

	}
}
